@@ -5,7 +5,7 @@ use Locale::Msgfmt::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub new {
   my $class = shift;
@@ -105,4 +105,18 @@ sub parse {
   $self->read_po($pofile);
 }
 
+=head1 NAME
+
+Locale::Msgfmt::po - class used internally by Locale::Msgfmt
+
+=head1 SYNOPSIS
+
+This module shouldn't be used by other software.
+
+=head1 SEE ALSO
+
+L<Locale::Msgfmt>
+
+=cut
+
 1;
